==> jc-1.4.0.tar.gz: java/awt/Label__24AccessibleAWTLabel.h <==
// public class java.awt.Label$AccessibleAWTLabel

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6e515cdd74d34ccf java_awt_Label__24AccessibleAWTLabel
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Label__24AccessibleAWTLabel_H_
#define _JC_java_awt_Label__24AccessibleAWTLabel_H_

// Forward structure declarations
struct _jc_java_awt_Label$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$sub_refs	_jc_java_awt_Label__24AccessibleAWTLabel$sub_refs;
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$sub_nonrefs	_jc_java_awt_Label__24AccessibleAWTLabel$sub_nonrefs;
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$refs	_jc_java_awt_Label__24AccessibleAWTLabel$refs;
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$nonrefs	_jc_java_awt_Label__24AccessibleAWTLabel$nonrefs;
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$object	_jc_java_awt_Label__24AccessibleAWTLabel$object;

typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$fields_struct	_jc_java_awt_Label__24AccessibleAWTLabel$fields_struct;
typedef const struct _jc_java_awt_Label__24AccessibleAWTLabel$vmethods	_jc_java_awt_Label__24AccessibleAWTLabel$vmethods;
typedef const struct _jc_java_awt_Label__24AccessibleAWTLabel$vtable	_jc_java_awt_Label__24AccessibleAWTLabel$vtable;
typedef const struct _jc_java_awt_Label__24AccessibleAWTLabel$vtype	_jc_java_awt_Label__24AccessibleAWTLabel$vtype;

// Class fields structure
struct _jc_java_awt_Label__24AccessibleAWTLabel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Label__24AccessibleAWTLabel$fields_struct _jc_java_awt_Label__24AccessibleAWTLabel$class_fields;

// Constructors
extern void _jc_java_awt_Label__24AccessibleAWTLabel$method$_init$4274442616a31251(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *, struct _jc_java_awt_Label$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_awt_Label__24AccessibleAWTLabel$method$getAccessibleName$2c9023476354d155(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *);
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Label__24AccessibleAWTLabel$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Label__24AccessibleAWTLabel$method_info$getAccessibleName$2c9023476354d155;
extern _jc_method _jc_java_awt_Label__24AccessibleAWTLabel$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_Label__24AccessibleAWTLabel$vmethods {
	struct _jc_java_lang_String$object	*(*getAccessibleName$2c9023476354d155)(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *);
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *);
};

// Vtable
struct _jc_java_awt_Label__24AccessibleAWTLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Label__24AccessibleAWTLabel$vmethods	java_awt_Label__24AccessibleAWTLabel;
};

// Vtype
struct _jc_java_awt_Label__24AccessibleAWTLabel$vtype {
	_jc_type			type;
	_jc_java_awt_Label__24AccessibleAWTLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Label__24AccessibleAWTLabel$sub_refs {
	struct _jc_java_awt_Label$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Label__24AccessibleAWTLabel$refs {
    _jc_java_awt_Label__24AccessibleAWTLabel$sub_refs	java_awt_Label__24AccessibleAWTLabel;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Label__24AccessibleAWTLabel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Label__24AccessibleAWTLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Label__24AccessibleAWTLabel$sub_nonrefs	java_awt_Label__24AccessibleAWTLabel;
};

// Object instance structure
struct _jc_java_awt_Label__24AccessibleAWTLabel$object {
	_jc_java_awt_Label__24AccessibleAWTLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Label__24AccessibleAWTLabel$vtype	*vtype;
	_jc_java_awt_Label__24AccessibleAWTLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Label__24AccessibleAWTLabel$vtype _jc_java_awt_Label__24AccessibleAWTLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Label__24AccessibleAWTLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Label__24AccessibleAWTLabel$class_object;

#endif	/* _JC_java_awt_Label__24AccessibleAWTLabel_H_ */

==> jc-1.4.5.tar.gz: java/awt/Label__24AccessibleAWTLabel.h <==
// public class java.awt.Label$AccessibleAWTLabel

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6e515cdd74d34ccf java_awt_Label__24AccessibleAWTLabel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Label__24AccessibleAWTLabel_H_
#define _JC_java_awt_Label__24AccessibleAWTLabel_H_

// Forward structure declarations
struct _jc_java_awt_Label$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$sub_refs	_jc_java_awt_Label__24AccessibleAWTLabel$sub_refs;
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$sub_nonrefs	_jc_java_awt_Label__24AccessibleAWTLabel$sub_nonrefs;
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$refs	_jc_java_awt_Label__24AccessibleAWTLabel$refs;
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$nonrefs	_jc_java_awt_Label__24AccessibleAWTLabel$nonrefs;
typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$object	_jc_java_awt_Label__24AccessibleAWTLabel$object;

typedef struct _jc_java_awt_Label__24AccessibleAWTLabel$fields_struct	_jc_java_awt_Label__24AccessibleAWTLabel$fields_struct;
typedef const struct _jc_java_awt_Label__24AccessibleAWTLabel$vmethods	_jc_java_awt_Label__24AccessibleAWTLabel$vmethods;
typedef const struct _jc_java_awt_Label__24AccessibleAWTLabel$vtable	_jc_java_awt_Label__24AccessibleAWTLabel$vtable;
typedef const struct _jc_java_awt_Label__24AccessibleAWTLabel$vtype	_jc_java_awt_Label__24AccessibleAWTLabel$vtype;

// Class fields structure
struct _jc_java_awt_Label__24AccessibleAWTLabel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Label__24AccessibleAWTLabel$fields_struct _jc_java_awt_Label__24AccessibleAWTLabel$class_fields;

// Constructors
extern void _jc_java_awt_Label__24AccessibleAWTLabel$method$_init$4274442616a31251(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *, struct _jc_java_awt_Label$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_awt_Label__24AccessibleAWTLabel$method$getAccessibleName$2c9023476354d155(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Label__24AccessibleAWTLabel$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Label__24AccessibleAWTLabel$method_info$getAccessibleName$2c9023476354d155;
extern _jc_method _jc_java_awt_Label__24AccessibleAWTLabel$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_Label__24AccessibleAWTLabel$vmethods {
	struct _jc_java_lang_String$object	*(*getAccessibleName$2c9023476354d155)(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Label__24AccessibleAWTLabel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Label__24AccessibleAWTLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Label__24AccessibleAWTLabel$vmethods	java_awt_Label__24AccessibleAWTLabel;
};

// Vtype
struct _jc_java_awt_Label__24AccessibleAWTLabel$vtype {
	_jc_type			type;
	_jc_java_awt_Label__24AccessibleAWTLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Label__24AccessibleAWTLabel$sub_refs {
	struct _jc_java_awt_Label$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Label__24AccessibleAWTLabel$refs {
    _jc_java_awt_Label__24AccessibleAWTLabel$sub_refs	java_awt_Label__24AccessibleAWTLabel;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Label__24AccessibleAWTLabel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Label__24AccessibleAWTLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Label__24AccessibleAWTLabel$sub_nonrefs	java_awt_Label__24AccessibleAWTLabel;
};

// Object instance structure
struct _jc_java_awt_Label__24AccessibleAWTLabel$object {
	_jc_java_awt_Label__24AccessibleAWTLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Label__24AccessibleAWTLabel$vtype	*vtype;
	_jc_java_awt_Label__24AccessibleAWTLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Label__24AccessibleAWTLabel$vtype _jc_java_awt_Label__24AccessibleAWTLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Label__24AccessibleAWTLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Label__24AccessibleAWTLabel$class_object;

#endif	/* _JC_java_awt_Label__24AccessibleAWTLabel_H_ */
